from IPython.core.display import display, HTML

def hdp_test(_fun, _expected, *_input):
    ok__message = '<span style="color: green;"><b>[OK]</b> Caso de prueba correcto para entrada {0}</span>'
    err_message = '<span style="color: red;"><b>[ERROR]</b> Para entrada {0} se espera {1} pero se obtuvo {2}</span>'
    try:
        _res = _fun(*_input)
        assert _res == _expected
        display(HTML(ok__message.format(_input)))
    except:
        display(HTML(err_message.format(_input, _expected, _res)))





name = "hdptest"

from IPython.core.magic import register_cell_magic
@register_cell_magic
def hdptest(line, cell):
    get_ipython().run_cell_magic('run_pytest[clean]', ' -qq -s --disable-warnings', cell)

del hdptest

import ipytest
import pytest
ipytest.config(rewrite_asserts=True, magics=True, tempfile_fallback=True)

from .hdptest import hdp_test




import pytest

def pytest_report_teststatus(report):
    category, short, verbose = '', '', ''
    if hasattr(report, 'wasxfail'):
        if report.skipped:
            category = 'xfailed'
            verbose = 'xfail'
        elif report.passed:
            category = 'xpassed'
            verbose = ('XPASS', {'yellow': True})
        return (category, short, verbose)
    elif report.when in ('setup', 'teardown'):
        if report.failed:
            category = 'error'
            verbose = 'ERROR'
        elif report.skipped:
            category = 'skipped'
            verbose = 'SKIPPED'
        return (category, short, verbose)
    category = report.outcome
    verbose = category.upper()
    return (category, short, verbose)


import setuptools

setuptools.setup(
    name='hdptest',
    version='0.3',
    scripts=[],
    author="Ismael Figueroa",
    author_email="ifigueroap@gmail.com",
    description="Mecanismo simple para tests en Jupyter Notebooks",
    url="https://github.com/ifigueroap/hdptest",
    packages=setuptools.find_packages()
)